@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
 """aios = asyncio + os"""
+from __future__ import annotations
+
 import os
 
 from asyncify import asyncify
 from shellfish.aios import _path
 
 __all__ = (
+    "chmod",
     "makedirs",
     "mkdir",
     "path",
@@ -19,6 +22,7 @@ __all__ = (
 
 path = _path
 
+chmod = asyncify(os.chmod)
 makedirs = asyncify(os.makedirs)
 rename = asyncify(os.rename)
 replace = asyncify(os.replace)
